Python Module Index — A Python Environment for (phylogenetic) Tree Exploration

### Navigation

- index
- modules |
- ETE documentation »

# Python Module Index

e

| e |
| `ete2` | provides main objects and modules
| `ete2.clustering` | Extends Tree object: link trees to numeric matrices, perform cluster validation analysis, visualize node profiles
| `ete2.nexml` |
| `ete2.parser.seqgroup` |
| `ete2.phylo` |
| `ete2.phyloxml` |
| `ete2.treeview` |
| `ete2.webplugin` |

### Navigation

- index
- modules |
- ETE documentation »